from setuptools import setup

setup(name='PoL_gauss_bino_distribution',
      version='0.2',
      description='Gaussian & Binomial distributions',
      packages=['PoL_gauss_bino_distribution'],
      auther = 'Kuldeep Saxena',
      author_email = 'saxenak02@gmail.com',
      zip_safe=False)
